@@ -46,6 +46,17 @@ class Alarms:
         '''
         :param lower_alarm_interval_index: 
         :param upper_alarm_interval_index: 
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            import aws_cdk.aws_autoscaling_common as autoscaling_common
+            
+            alarms = autoscaling_common.Alarms(
+                lower_alarm_interval_index=123,
+                upper_alarm_interval_index=123
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {}
         if lower_alarm_interval_index is not None:
@@ -90,6 +101,23 @@ class ArbitraryIntervals:
         '''
         :param absolute: 
         :param intervals: 
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            import aws_cdk.aws_autoscaling_common as autoscaling_common
+            
+            arbitrary_intervals = autoscaling_common.ArbitraryIntervals(
+                absolute=False,
+                intervals=[autoscaling_common.ScalingInterval(
+                    change=123,
+            
+                    # the properties below are optional
+                    lower=123,
+                    upper=123
+                )]
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "absolute": absolute,
@@ -123,20 +151,34 @@ class ArbitraryIntervals:
 @jsii.data_type(
     jsii_type="@aws-cdk/aws-autoscaling-common.CompleteScalingInterval",
     jsii_struct_bases=[],
-    name_mapping={"lower": "lower", "upper": "upper", "change": "change"},
+    name_mapping={"change": "change", "lower": "lower", "upper": "upper"},
 )
 class CompleteScalingInterval:
     def __init__(
         self,
         *,
+        change: typing.Optional[jsii.Number] = None,
         lower: jsii.Number,
         upper: jsii.Number,
-        change: typing.Optional[jsii.Number] = None,
     ) -> None:
         '''
+        :param change: 
         :param lower: 
         :param upper: 
-        :param change: 
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            import aws_cdk.aws_autoscaling_common as autoscaling_common
+            
+            complete_scaling_interval = autoscaling_common.CompleteScalingInterval(
+                lower=123,
+                upper=123,
+            
+                # the properties below are optional
+                change=123
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "lower": lower,
@@ -145,6 +187,11 @@ class CompleteScalingInterval:
         if change is not None:
             self._values["change"] = change
 
+    @builtins.property
+    def change(self) -> typing.Optional[jsii.Number]:
+        result = self._values.get("change")
+        return typing.cast(typing.Optional[jsii.Number], result)
+
     @builtins.property
     def lower(self) -> jsii.Number:
         result = self._values.get("lower")
@@ -157,11 +204,6 @@ class CompleteScalingInterval:
         assert result is not None, "Required property 'upper' is missing"
         return typing.cast(jsii.Number, result)
 
-    @builtins.property
-    def change(self) -> typing.Optional[jsii.Number]:
-        result = self._values.get("change")
-        return typing.cast(typing.Optional[jsii.Number], result)
-
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -226,6 +268,20 @@ class ScalingInterval:
         :param change: The capacity adjustment to apply in this interval. The number is interpreted differently based on AdjustmentType: - ChangeInCapacity: add the adjustment to the current capacity. The number can be positive or negative. - PercentChangeInCapacity: add or remove the given percentage of the current capacity to itself. The number can be in the range [-100..100]. - ExactCapacity: set the capacity to this number. The number must be positive.
         :param lower: The lower bound of the interval. The scaling adjustment will be applied if the metric is higher than this value. Default: Threshold automatically derived from neighbouring intervals
         :param upper: The upper bound of the interval. The scaling adjustment will be applied if the metric is lower than this value. Default: Threshold automatically derived from neighbouring intervals
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            import aws_cdk.aws_autoscaling_common as autoscaling_common
+            
+            scaling_interval = autoscaling_common.ScalingInterval(
+                change=123,
+            
+                # the properties below are optional
+                lower=123,
+                upper=123
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "change": change,
